@@ -59,7 +59,7 @@ additionalfiles.generate(DOMAIN, PATH, "share/applications/mintstick-format-kde.
 
 prefix="""[Nemo Action]
 Active=true
-Exec=mintstick -m iso -i "%F"
+Exec=mintstick -m iso -i %F
 Icon-Name=media-removable-symbolic
 Selection=S
 Extensions=iso;img;
@@ -76,6 +76,15 @@ Conditions=removable;
 """
 additionalfiles.generate(DOMAIN, PATH, "share/nemo/actions/mintstick-format.nemo_action", prefix, _("Format"), _("Format a USB stick"), "")
 
+prefix="""[Nemo Action]
+Active=true
+Exec=mint-iso-verify %F
+Icon-Name=application-certificate-symbolic
+Selection=S
+Extensions=iso;img;
+"""
+additionalfiles.generate(DOMAIN, PATH, "share/nemo/actions/mintstick-verify.nemo_action", prefix, _("Verify"), _("Verify the authenticity and integrity of the image"), "")
+
 prefix="""<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE policyconfig PUBLIC
  "-//freedesktop//DTD PolicyKit Policy Configuration 1.0//EN"
