@@ -1,12 +1,11 @@
 #!/usr/bin/python3
 
-from subprocess import Popen, PIPE, call, STDOUT
+from subprocess import Popen, PIPE
 import getopt
 import gettext
 import gi
 import locale
 import os
-import re
 import signal
 import subprocess
 import sys
@@ -16,7 +15,7 @@ gi.require_version('Gtk', '3.0')
 gi.require_version('UDisks', '2.0')
 gi.require_version('XApp', '1.0')
 
-from gi.repository import GObject, Gio, Polkit, Gtk, GLib, UDisks, XApp
+from gi.repository import Polkit, Gtk, GLib, UDisks, XApp
 
 try:
     gi.require_version('Unity', '7.0')
@@ -235,7 +234,7 @@ class MintStick:
     def file_selected(self, widget):
         self.activate_devicelist()
         filename = self.chooser.get_filename()
-        if filename != None and os.path.exists(filename):
+        if filename is not None and os.path.exists(filename):
             self.verify_button.set_sensitive(True)
         else:
             self.verify_button.set_sensitive(False)
@@ -497,7 +496,7 @@ if __name__ == "__main__":
             filesystem = a
         elif o in ("-m", "--mode"):
             mode = a
-        elif o in "--debug":
+        elif o == "--debug":
             debug = True
 
     argc = len(sys.argv)
