@@ -1,11 +1,9 @@
 #!/usr/bin/python3
 
-import subprocess
-from subprocess import Popen,PIPE,call,STDOUT
 import os, sys
 import getopt
 sys.path.append('/usr/lib/mintstick')
-from mountutils import *
+from mountutils import do_umount
 import parted
 
 def raw_write(source, target):
@@ -14,17 +12,16 @@ def raw_write(source, target):
     size=0
     input = open(source, 'rb')
     total_size = float(os.path.getsize(source))
-    #print total_size
 
     # Check if the ISO can fit ... :)
     device = parted.getDevice(target)
     device_size = device.getLength() * device.sectorSize
-    if (device.getLength() * device.sectorSize) < float(os.path.getsize(source)):
+    if device_size < float(os.path.getsize(source)):
         input.close()
         print("nospace")
         exit(3)
 
-    increment = total_size / 100;
+    increment = total_size / 100
 
     written = 0
     output = open(target, 'wb')
@@ -68,9 +65,9 @@ def main():
             print("-t|--target          : target device path\n")
             print("Example : %s -s /foo/image.iso -t /dev/sdj" % sys.argv[0])
             sys.exit(0)
-        elif o in ("-s"):
+        elif o == "-s":
             source = a
-        elif o in ("-t"):
+        elif o == "-t":
             target = a
 
     argc = len(sys.argv)
